@@ -1,5 +1,3 @@
-require 'omniauth'
-
 module OmniAuth
   class Builder < ::Rack::Builder
     def initialize(app, &block)
@@ -21,6 +19,18 @@ module OmniAuth
       OmniAuth.config.on_failure = block
     end
 
+    def before_options_phase(&block)
+      OmniAuth.config.before_options_phase = block
+    end
+
+    def before_request_phase(&block)
+      OmniAuth.config.before_request_phase = block
+    end
+
+    def before_callback_phase(&block)
+      OmniAuth.config.before_callback_phase = block
+    end
+
     def configure(&block)
       OmniAuth.configure(&block)
     end
