@@ -1,5 +1,8 @@
 class OmniAuth::Test::PhonySession
-  def initialize(app); @app = app end
+  def initialize(app)
+    @app = app
+  end
+
   def call(env)
     @session ||= (env['rack.session'] || {})
     env['rack.session'] = @session
