@@ -5,14 +5,17 @@ SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter[
   SimpleCov::Formatter::HTMLFormatter,
   Coveralls::SimpleCov::Formatter
 ]
-SimpleCov.start
+SimpleCov.start do
+  add_filter '/spec/'
+  minimum_coverage(93.05)
+end
 
 require 'rspec'
 require 'rack/test'
 require 'omniauth'
 require 'omniauth/test'
 
-OmniAuth.config.logger = Logger.new("/dev/null")
+OmniAuth.config.logger = Logger.new('/dev/null')
 
 RSpec.configure do |config|
   config.include Rack::Test::Methods
@@ -24,23 +27,29 @@ end
 
 class ExampleStrategy
   include OmniAuth::Strategy
-  option :name, 'test'
-  def call(env); self.call!(env) end
   attr_reader :last_env
+  option :name, 'test'
+
+  def call(env)
+    self.call!(env)
+  end
+
   def initialize(*args, &block)
     super
     @fail = nil
   end
+
   def request_phase
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
-    raise "Request Phase"
+    fail('Request Phase')
   end
+
   def callback_phase
     @fail = fail!(options[:failure]) if options[:failure]
     @last_env = env
     return @fail if @fail
-    raise "Callback Phase"
+    fail('Callback Phase')
   end
 end
