@@ -1,47 +1,47 @@
 require 'helper'
 
 describe OmniAuth::Builder do
-  describe "#provider" do
-    it "translates a symbol to a constant" do
-      OmniAuth::Strategies.should_receive(:const_get).with('MyStrategy').and_return(Class.new)
+  describe '#provider' do
+    it 'translates a symbol to a constant' do
+      expect(OmniAuth::Strategies).to receive(:const_get).with('MyStrategy').and_return(Class.new)
       OmniAuth::Builder.new(nil) do
         provider :my_strategy
       end
     end
 
-    it "accepts a class" do
+    it 'accepts a class' do
       class ::ExampleClass; end
 
-      expect{
+      expect do
         OmniAuth::Builder.new(nil) do
           provider ::ExampleClass
         end
-      }.not_to raise_error
+      end.not_to raise_error
     end
 
     it "raises a helpful LoadError message if it can't find the class" do
-      expect {
+      expect do
         OmniAuth::Builder.new(nil) do
           provider :lorax
         end
-      }.to raise_error(LoadError, "Could not find matching strategy for :lorax. You may need to install an additional gem (such as omniauth-lorax).")
+      end.to raise_error(LoadError, 'Could not find matching strategy for :lorax. You may need to install an additional gem (such as omniauth-lorax).')
     end
   end
 
-  describe "#options" do
-    it "merges provided options in" do
+  describe '#options' do
+    it 'merges provided options in' do
       k = Class.new
       b = OmniAuth::Builder.new(nil)
-      b.should_receive(:use).with(k, :foo => 'bar', :baz => 'tik')
+      expect(b).to receive(:use).with(k, :foo => 'bar', :baz => 'tik')
 
       b.options :foo => 'bar'
       b.provider k, :baz => 'tik'
     end
 
-    it "adds an argument if no options are provided" do
+    it 'adds an argument if no options are provided' do
       k = Class.new
       b = OmniAuth::Builder.new(nil)
-      b.should_receive(:use).with(k, :foo => 'bar')
+      expect(b).to receive(:use).with(k, :foo => 'bar')
 
       b.options :foo => 'bar'
       b.provider k
